package com.ruoyi.basetyre.mapper;

import java.util.List;
import com.ruoyi.basetyre.domain.BaseTyre;

/**
 * 轮胎基础信息Mapper接口
 * 
 * @author Yangwl
 * @date 2023-02-06
 */
public interface BaseTyreMapper 
{
    /**
     * 查询轮胎基础信息
     * 
     * @param id 轮胎基础信息主键
     * @return 轮胎基础信息
     */
    public BaseTyre selectBaseTyreById(String id);

    /**
     * 查询轮胎基础信息列表
     * 
     * @param baseTyre 轮胎基础信息
     * @return 轮胎基础信息集合
     */
    public List<BaseTyre> selectBaseTyreList(BaseTyre baseTyre);

    /**
     * 新增轮胎基础信息
     * 
     * @param baseTyre 轮胎基础信息
     * @return 结果
     */
    public int insertBaseTyre(BaseTyre baseTyre);

    /**
     * 修改轮胎基础信息
     * 
     * @param baseTyre 轮胎基础信息
     * @return 结果
     */
    public int updateBaseTyre(BaseTyre baseTyre);

    /**
     * 删除轮胎基础信息
     * 
     * @param id 轮胎基础信息主键
     * @return 结果
     */
    public int deleteBaseTyreById(String id);

    /**
     * 批量删除轮胎基础信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBaseTyreByIds(String[] ids);
}
